
.. image:: https://readthedocs.org/projects/wow-wtf/badge/?version=latest
    :target: https://wow-wtf.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/wow_wtf-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/wow_wtf-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/wow_wtf-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/wow_wtf-project

.. image:: https://img.shields.io/pypi/v/wow-wtf.svg
    :target: https://pypi.python.org/pypi/wow-wtf

.. image:: https://img.shields.io/pypi/l/wow-wtf.svg
    :target: https://pypi.python.org/pypi/wow-wtf

.. image:: https://img.shields.io/pypi/pyversions/wow-wtf.svg
    :target: https://pypi.python.org/pypi/wow-wtf

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/wow_wtf-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/wow_wtf-project

------

.. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://wow-wtf.readthedocs.io/en/latest/

.. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://wow-wtf.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/wow_wtf-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/wow_wtf-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/wow_wtf-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/wow-wtf#files


Welcome to ``wow_wtf`` Documentation
==============================================================================
.. image:: https://wow-wtf.readthedocs.io/en/latest/_static/wow_wtf-logo.png
    :target: https://wow-wtf.readthedocs.io/en/latest/

``World of Warcraft/WTF`` configuration management tool.

该项目是一个用于管理魔兽世界客户端 WTF 配置文件的工具. 该工具本身用 Python 实现, 功能非常强大, 可扩展性也很强. 该工具不是一个图形界面软件, 而是一个编程库. 我用它管理着 2 个不同的魔兽世界资料片 (WotLK 和 MOP), 4 个不同的服务器 (包括一个 retail 官服和 3 个不同的私服), 共计 50 多个游戏账号, 180 多个人物角色的配置文件 (我喜欢玩多开单刷).


.. _install:

Install
------------------------------------------------------------------------------

``wow_wtf`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install wow-wtf

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade wow-wtf
